@@ -121,12 +121,12 @@ class ModulatorDialog(QDialog):
         return mod
 
     def set_ui_for_current_modulator(self):
-        index = self.ui.comboBoxModulationType.findText("*(" + self.current_modulator.modulation_type_str + ")",
+        index = self.ui.comboBoxModulationType.findText("*(" + self.current_modulator.modulation_type + ")",
                                                         Qt.MatchWildcard)
         self.ui.comboBoxModulationType.setCurrentIndex(index)
         self.ui.doubleSpinBoxCarrierFreq.setValue(self.current_modulator.carrier_freq_hz)
         self.ui.doubleSpinBoxCarrierPhase.setValue(self.current_modulator.carrier_phase_deg)
-        self.ui.spinBoxBitLength.setValue(self.current_modulator.samples_per_bit)
+        self.ui.spinBoxBitLength.setValue(self.current_modulator.samples_per_symbol)
         self.ui.spinBoxSampleRate.setValue(self.current_modulator.sample_rate)
         self.ui.spinBoxParameter0.setValue(self.current_modulator.param_for_zero)
         self.ui.spinBoxParameter1.setValue(self.current_modulator.param_for_one)
@@ -374,7 +374,7 @@ class ModulatorDialog(QDialog):
 
     @pyqtSlot()
     def on_bit_len_changed(self):
-        self.current_modulator.samples_per_bit = self.ui.spinBoxBitLength.value()
+        self.current_modulator.samples_per_symbol = self.ui.spinBoxBitLength.value()
         self.draw_carrier()
         self.draw_data_bits()
         self.draw_modulated()
@@ -443,10 +443,10 @@ class ModulatorDialog(QDialog):
 
     @pyqtSlot()
     def on_modulation_type_changed(self):
-        if self.current_modulator.modulation_type_str == self.__cur_selected_mod_type():
+        if self.current_modulator.modulation_type == self.__cur_selected_mod_type():
             write_standard_parameters = False
         else:
-            self.current_modulator.modulation_type_str = self.__cur_selected_mod_type()
+            self.current_modulator.modulation_type = self.__cur_selected_mod_type()
             write_standard_parameters = True
 
         self.__set_gauss_ui_visibility(self.__cur_selected_mod_type() == "GFSK")
